LogpointApi.Core.Search (logpoint_api v2.2.0)

Copy Markdown View Source

Search logs and retrieve instance data from Logpoint.

Wraps the Search API. Use LogpointApi.search_params/4 to build the query struct.

Summary

Functions

Get devices from the Logpoint instance.

Create a search and get its search ID.

Retrieve the search result for a given search ID.

Get live searches from the Logpoint instance.

Get loginspects from the Logpoint instance.

Get logpoint repos from the Logpoint instance.

Get user preferences from the Logpoint instance.

Functions

devices(client)

@spec devices(LogpointApi.Data.Client.t()) :: {:ok, map()} | {:error, term()}

Get devices from the Logpoint instance.

get_id(client, query)

@spec get_id(LogpointApi.Data.Client.t(), LogpointApi.Data.SearchParams.t()) ::
  {:ok, map()} | {:error, term()}

Create a search and get its search ID.

get_result(client, search_id)

@spec get_result(LogpointApi.Data.Client.t(), String.t()) ::
  {:ok, map()} | {:error, term()}

Retrieve the search result for a given search ID.

livesearches(client)

@spec livesearches(LogpointApi.Data.Client.t()) :: {:ok, map()} | {:error, term()}

Get live searches from the Logpoint instance.

loginspects(client)

@spec loginspects(LogpointApi.Data.Client.t()) :: {:ok, map()} | {:error, term()}

Get loginspects from the Logpoint instance.

logpoint_repos(client)

@spec logpoint_repos(LogpointApi.Data.Client.t()) :: {:ok, map()} | {:error, term()}

Get logpoint repos from the Logpoint instance.

user_preference(client)

@spec user_preference(LogpointApi.Data.Client.t()) :: {:ok, map()} | {:error, term()}

Get user preferences from the Logpoint instance.